import { type PathLike } from 'fs';
export declare class DataStore {
    #private;
    constructor();
    get(collectionName: string, key: string): any;
    entries(collectionName: string): Array<[id: string, any]>;
    values(collectionName: string): Array<unknown>;
    keys(collectionName: string): Array<string>;
    set(collectionName: string, key: string, value: unknown): void;
    delete(collectionName: string, key: string): void;
    clear(collectionName: string): void;
    has(collectionName: string, key: string): boolean;
    hasCollection(collectionName: string): boolean;
    collections(): Map<string, Map<string, any>>;
    scopedStore(collectionName: string): ScopedDataStore;
    metaStore(collectionName: string): MetaStore;
    toString(): string;
    writeToDisk(filePath: PathLike): Promise<void>;
    static fromDisk(filePath: PathLike): Promise<DataStore>;
    static fromString(str: string): DataStore;
    static fromModule(): Promise<DataStore>;
    static fromJSON(entries: Array<[string, Array<[string, any]>]>): DataStore;
}
export interface ScopedDataStore {
    get: (key: string) => unknown;
    entries: () => Array<[id: string, unknown]>;
    set: (key: string, value: unknown) => void;
    values: () => Array<unknown>;
    keys: () => Array<string>;
    delete: (key: string) => void;
    clear: () => void;
    has: (key: string) => boolean;
}
/**
 * A key-value store for metadata strings. Useful for storing things like sync tokens.
 */
export interface MetaStore {
    get: (key: string) => string | undefined;
    set: (key: string, value: string) => void;
    has: (key: string) => boolean;
}
export declare const globalDataStore: {
    get: () => Promise<DataStore>;
    set: (store: DataStore) => void;
};
